==> Paws-0.34.tar.gz: Paws-0.34/lib/Paws/SSM/DocumentVersionInfo.pm <==
package Paws::SSM::DocumentVersionInfo;
  use Moose;
  has CreatedDate => (is => 'ro', isa => 'Str');
  has DocumentVersion => (is => 'ro', isa => 'Str');
  has IsDefaultVersion => (is => 'ro', isa => 'Bool');
  has Name => (is => 'ro', isa => 'Str');
1;

### main pod documentation begin ###

=head1 NAME

Paws::SSM::DocumentVersionInfo

=head1 USAGE

This class represents one of two things:

=head3 Arguments in a call to a service

Use the attributes of this class as arguments to methods. You shouldn't make instances of this class. 
Each attribute should be used as a named argument in the calls that expect this type of object.

As an example, if Att1 is expected to be a Paws::SSM::DocumentVersionInfo object:

  $service_obj->Method(Att1 => { CreatedDate => $value, ..., Name => $value  });

=head3 Results returned from an API call

Use accessors for each attribute. If Att1 is expected to be an Paws::SSM::DocumentVersionInfo object:

  $result = $service_obj->Method(...);
  $result->Att1->CreatedDate

=head1 DESCRIPTION

Version information about the document.

=head1 ATTRIBUTES


=head2 CreatedDate => Str

  The date the document was created.


=head2 DocumentVersion => Str

  The document version.


=head2 IsDefaultVersion => Bool

  An identifier for the default version of the document.


=head2 Name => Str

  The document name.



=head1 SEE ALSO

This class forms part of L<Paws>, describing an object used in L<Paws::SSM>

=head1 BUGS and CONTRIBUTIONS

The source code is located here: https://github.com/pplu/aws-sdk-perl

Please report bugs to: https://github.com/pplu/aws-sdk-perl/issues

=cut

==> Paws-0.38.tar.gz: Paws-0.38/lib/Paws/SSM/DocumentVersionInfo.pm <==
package Paws::SSM::DocumentVersionInfo;
  use Moose;
  has CreatedDate => (is => 'ro', isa => 'Str');
  has DocumentFormat => (is => 'ro', isa => 'Str');
  has DocumentVersion => (is => 'ro', isa => 'Str');
  has IsDefaultVersion => (is => 'ro', isa => 'Bool');
  has Name => (is => 'ro', isa => 'Str');
1;

### main pod documentation begin ###

=head1 NAME

Paws::SSM::DocumentVersionInfo

=head1 USAGE

This class represents one of two things:

=head3 Arguments in a call to a service

Use the attributes of this class as arguments to methods. You shouldn't make instances of this class. 
Each attribute should be used as a named argument in the calls that expect this type of object.

As an example, if Att1 is expected to be a Paws::SSM::DocumentVersionInfo object:

  $service_obj->Method(Att1 => { CreatedDate => $value, ..., Name => $value  });

=head3 Results returned from an API call

Use accessors for each attribute. If Att1 is expected to be an Paws::SSM::DocumentVersionInfo object:

  $result = $service_obj->Method(...);
  $result->Att1->CreatedDate

=head1 DESCRIPTION

Version information about the document.

=head1 ATTRIBUTES


=head2 CreatedDate => Str

  The date the document was created.


=head2 DocumentFormat => Str

  The document format, either JSON or YAML.


=head2 DocumentVersion => Str

  The document version.


=head2 IsDefaultVersion => Bool

  An identifier for the default version of the document.


=head2 Name => Str

  The document name.



=head1 SEE ALSO

This class forms part of L<Paws>, describing an object used in L<Paws::SSM>

=head1 BUGS and CONTRIBUTIONS

The source code is located here: L<https://github.com/pplu/aws-sdk-perl>

Please report bugs to: L<https://github.com/pplu/aws-sdk-perl/issues>

=cut
